@@ -130,7 +130,7 @@ use Moose;
 use String::Util qw/hascontent trim/;
 
 
-our $VERSION = '1.10';
+our $VERSION = '1.20';
 
 
 =head1 METHODS & ATTRIBUTES
@@ -410,7 +410,11 @@ sub printf {
 	$date   //= $self->date_format;
 	$format //= $self->format;
 	
-	sprintf $format, $self->start->printf( $date ), $self->end->printf( $date );
+	no warnings;
+	sprintf $format, 
+		$self->start->printf( $date ), 
+		$self->end->printf( $date )
+	;
 }
 
 
@@ -658,7 +662,7 @@ sub _add {
 sub _date_format_for {
 	my $self = shift;
 	
-	my $shortest = shift [sort @_];
+	my $shortest = (sort @_)[0];
 
 	if ($shortest =~ m/year/i)     { $self->date_format( '%Y'        ); }
 	elsif ($shortest =~ m/month/i) { $self->date_format( '%B %Y'     ); } 
@@ -716,21 +720,28 @@ sub _normalize {
 B<Date::Manip::Range> only supports English range operators. Translations 
 welcome.
 
-=head1 AUTHOR
-
-Robert Wohlfarth <rbwohlfarth@gmail.com>
-
 =head1 SEE ALSO
 
 L<Date::Manip>
 
-=head1 LICENSE
+=head1 REPOSITORY
 
-Copyright (c) 2015  Robert Wohlfarth
+L<https://github.com/rbwohlfarth/Date-Manip-Range>
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself. This software comes with NO WARRANTY of any
-kind.
+=head1 AUTHOR
+
+Robert Wohlfarth <rbwohlfarth@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2016  Robert Wohlfarth
+
+This module is free software; you can redistribute it and/or modify it 
+under the same terms as Perl 5.10.0. For more details, see the full text 
+of the licenses in the directory LICENSES.
+
+This program is distributed in the hope that it will be useful, but 
+without any warranty; without even the implied
 
 =cut
 
